==> bottender-compose-0.12.3.tgz: package/lib/index.js <==
"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const methods = require('./methods');

const predicates = require('./predicates');

const {
  not,
  and,
  or,
  alwaysTrue,
  alwaysFalse
} = require('./logic');

const {
  log,
  info,
  warn,
  error,
  createLogger
} = require('./logger');

const {
  isValidTemplate,
  compileTemplate
} = require('./utils');

const allMethods = methods.common.concat(methods.messenger).concat(methods.line).concat(methods.slack).concat(methods.telegram).concat(methods.viber).concat(methods.fb);
allMethods.forEach(({
  method,
  length,
  allowOptions
}) => {
  if (!exports[method]) {
    exports[method] = (...args) => {
      const fn = (context, ...otherArgs) => {
        const options = args[length - 1];

        if (fn._options) {
          // eslint-disable-next-line no-param-reassign
          args[length - 1] = _objectSpread({}, options, fn._options);
        }

        return context[method](...args.map(arg => {
          if (typeof arg === 'function') {
            return arg(context, ...otherArgs);
          }

          if (typeof arg === 'string' && isValidTemplate(arg)) {
            return compileTemplate(arg)(context);
          }

          return arg;
        }));
      };

      fn.argsLength = length;
      fn.allowOptions = allowOptions;
      return fn;
    };
  }
});
const allPredicates = predicates.messenger.concat(predicates.line).concat(predicates.slack).concat(predicates.telegram).concat(predicates.viber).concat(predicates.fb);
allPredicates.forEach(predicate => {
  if (!exports[predicate]) {
    exports[predicate] = () => context => context.event[predicate];
  }
});
exports._ = require('./_');
exports.branch = require('./branch');
exports.condition = require('./condition');
exports.match = require('./match');
exports.parallel = require('./parallel');
exports.platform = require('./platform');
exports.random = require('./random');
exports.series = require('./series');
exports.tryCatch = require('./tryCatch');
exports.weight = require('./weight');
exports.doNothing = require('./doNothing');
exports.repeat = require('./repeat');
exports.delay = require('./delay');
exports.setDisplayName = require('./setDisplayName');
exports.effect = require('./effect');
exports.attachOptions = require('./attachOptions');
/* Predicate */

exports.isTextMatch = predicates.isTextMatch;
exports.isPayloadMatch = predicates.isPayloadMatch;
exports.hasStateEqual = predicates.hasStateEqual;
/* Logic */

exports.not = not;
exports.and = and;
exports.or = or;
exports.alwaysTrue = alwaysTrue;
exports.alwaysFalse = alwaysFalse;
/* Logger */

exports.log = log;
exports.info = info;
exports.warn = warn;
exports.error = error;
exports.createLogger = createLogger;

==> bottender-compose-0.12.4.tgz: package/lib/index.js <==
"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const methods = require('./methods');

const predicates = require('./predicates');

const {
  not,
  and,
  or,
  alwaysTrue,
  alwaysFalse
} = require('./logic');

const {
  log,
  info,
  warn,
  error,
  createLogger
} = require('./logger');

const {
  isValidTemplate,
  compileTemplate
} = require('./utils');

const allMethods = methods.common.concat(methods.messenger).concat(methods.line).concat(methods.slack).concat(methods.telegram).concat(methods.viber).concat(methods.fb);
allMethods.forEach(({
  method,
  length,
  allowOptions
}) => {
  if (!exports[method]) {
    exports[method] = (...args) => {
      const fn = (context, ...otherArgs) => {
        const options = args[length - 1];

        if (fn._options) {
          // eslint-disable-next-line no-param-reassign
          args[length - 1] = _objectSpread({}, options, fn._options);
        }

        return context[method](...args.map(arg => {
          if (typeof arg === 'function') {
            return arg(context, ...otherArgs);
          }

          if (typeof arg === 'string' && isValidTemplate(arg)) {
            return compileTemplate(arg)(context, ...otherArgs);
          }

          return arg;
        }));
      };

      fn.argsLength = length;
      fn.allowOptions = allowOptions;
      return fn;
    };
  }
});
const allPredicates = predicates.messenger.concat(predicates.line).concat(predicates.slack).concat(predicates.telegram).concat(predicates.viber).concat(predicates.fb);
allPredicates.forEach(predicate => {
  if (!exports[predicate]) {
    exports[predicate] = () => context => context.event[predicate];
  }
});
exports._ = require('./_');
exports.branch = require('./branch');
exports.condition = require('./condition');
exports.match = require('./match');
exports.parallel = require('./parallel');
exports.platform = require('./platform');
exports.random = require('./random');
exports.series = require('./series');
exports.tryCatch = require('./tryCatch');
exports.weight = require('./weight');
exports.doNothing = require('./doNothing');
exports.repeat = require('./repeat');
exports.delay = require('./delay');
exports.setDisplayName = require('./setDisplayName');
exports.effect = require('./effect');
exports.attachOptions = require('./attachOptions');
/* Predicate */

exports.isTextMatch = predicates.isTextMatch;
exports.isPayloadMatch = predicates.isPayloadMatch;
exports.hasStateEqual = predicates.hasStateEqual;
/* Logic */

exports.not = not;
exports.and = and;
exports.or = or;
exports.alwaysTrue = alwaysTrue;
exports.alwaysFalse = alwaysFalse;
/* Logger */

exports.log = log;
exports.info = info;
exports.warn = warn;
exports.error = error;
exports.createLogger = createLogger;
